\name{loadGenomesFromVCF}
\alias{loadGenomesFromVCF}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  loadGenomesFromVCF
}
\description{
  Loads a single tumor genome (sample) or a set of genomes from a VCF
  file and determines the mutation frequencies according to a specific
  model of mutational signatures (Alexandrov or Shiraishi).
}
\usage{
loadGenomesFromVCF(file, numBases=5, type="Shiraishi", trDir=TRUE, refGenome=BSgenome.Hsapiens.UCSC.hg19::BSgenome.Hsapiens.UCSC.hg19, transcriptAnno=TxDb.Hsapiens.UCSC.hg19.knownGene::TxDb.Hsapiens.UCSC.hg19.knownGene, verbose=TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{file}{
    (Mandatory) The name of the VCF file (can be compressed with gzip).
  }
  \item{numBases}{
    (Mandatory) Total number of bases (mutated base and flanking bases)
    to be used for sequence patterns. Default: 5
  }
  \item{type}{
    (Mandatory) Singature model or type (Alexandrov or
    Shiraishi). Default: Shiraishi
  }
  \item{trDir}{
    (Mandatory) Specifies whether the transcription direction is taken
    into account in the signature model. If so, only mutations within
    genes can be considered. Default: TRUE
  }
  \item{refGenome}{
    (Mandatory) The reference genome (BSgenome) needed to extract
    sequence patterns. Default: BSgenome object for hg19.
  }
  \item{transcriptAnno}{
    (Optional) Transcript annotation (TxDb object) used to determine the
    transcription direction. This is required only if
    trDir=TRUE. Default: TxDb object for hg19.
  }
  \item{verbose}{
    (Optional) Print information about reading and processing the
    mutation data. Default: TRUE
  }
}
%\details{
%}
\value{
   A list containing the genomes in terms of frequencies of the mutated
   sequence patterns. This list can be used for decomposeTumorGenomes.
}
\references{
Krueger, Piro (2017) Identification of Mutational Signatures Active in
Individual Tumors. NETTAB 2017 - Methods, Tools & Platforms for
Personalized Medicine in the Big Data Era, October 16-18, 2017, Palermo,
Italy. PeerJ Preprints 5:e3257v1, 2017.\cr
http://rmpiro.net/index.html#downloads
}
\author{
  Rosario M. Piro\cr
  Freie Universitaet Berlin\cr
  Maintainer: Rosario M. Piro\cr
  E-Mail: <r.piro@fu-berlin.de> or <rmpiro@gmail.com>
}
%\note{
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
  decompTumor2Sig\cr
  decomposeTumorGenomes\cr
  loadGenomesFromVCF\cr
  getGenomesFromMutationFeatureData\cr
}
%\examples{
%}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{mutational signatures}
\keyword{mutation signatures}
\keyword{mutations}
\keyword{tumor genomes}
