\name{plotExplainedVariance}
\alias{plotExplainedVariance}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  plotExplainedVariance
}
\description{
  For a single genome and a given set of singatures, the function plots
  the variance of the genome's mutation load that can be explained with
  an increasing number of signatures (increasing subset of signatures).
  For each number K of signatures, the highest variance explained by any
  possible subset of K signatures will be plotted. This can help to
  evaluate what minimum threshlod for the explained variance should be
  used to decompose tumor genomes with the function
  decomposeTumorGenomes().
}
\usage{
plotExplainedVariance(genome, signatures, minExplainedVariance=NULL,
                      minNumSignatures=2, maxNumSignatures=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{genome}{
    (Mandatory) The mutation load of a single genome in Alexandrov- of
    Shiraishi-format, i.e. as vector or matrix. The format must be the
    same as the one used for the signatures (see below).
  }
  \item{signatures}{
    (Mandatory) The list of signatures (vectors, data.frames or
    matrices) for twhich the exposures were obtained. Each of the
    list objects represents one mutational signature. Vectors are used
    for Alexandrov signatures, data.frames or matrices for Shiraishi
    signatures.
  }
  \item{minExplainedVariance}{
    (Optional) If a numeric value between 0 and 1 is specified, the plot
    highlights the smallest subset of signatures that is sufficient to
    explain at least the specified fraction of the variance of the
    genome's mutation load. E.g., if minExplainedVariance=0.99 the
    smallest subset of signatures that explains at least 99\% of the
    variance will be highlighted.
  }
  \item{minNumSignatures}{
    (Optional) The plot will be generated only for K>=minNumSignatures.
  }
  \item{maxNumSignatures}{
    (Optional) The plot will be generated only for K<=minNumSignatures.
  }
}
%\details{
%}
\value{
  A numeric vectors of explained variances, one for each genome.
}
\references{
Krueger, Piro (2017) Identification of Mutational Signatures Active in
Individual Tumors. NETTAB 2017 - Methods, Tools & Platforms for
Personalized Medicine in the Big Data Era, October 16-18, 2017, Palermo,
Italy. PeerJ Preprints 5:e3257v1, 2017.\cr
http://rmpiro.net/index.html#downloads
}
\author{
  Rosario M. Piro\cr
  Freie Universitaet Berlin\cr
  Maintainer: Rosario M. Piro\cr
  E-Mail: <r.piro@fu-berlin.de> or <rmpiro@gmail.com>
}
%\note{
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
  decompTumor2Sig\cr
  decomposeTumorGenomes\cr
  computeExplainedVariance
}
%\examples{
%}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{mutational signatures}
\keyword{mutation signatures}
\keyword{mutations}
\keyword{tumor genomes}
